@@ -70,8 +70,12 @@ def addSwagger(apiInstance, appInstance):
     #
     # swaggerUi._static_folder = apiInstance.documentationFolderPath
     # log.debug(addSwagger, f'swaggerUi._static_folder at "{swaggerUi._static_folder}"')
+    import site
+    distPackage = str(site.getsitepackages()).replace('\\\\',self.globals.OS_SEPARATOR).replace('/',self.globals.OS_SEPARATOR).replace('\\',self.globals.OS_SEPARATOR)
 
-    swaggerUi._static_folder = f'{swaggerUi._static_folder}{globals.OS_SEPARATOR}'
+    swaggerUi._static_folder = f'dist{globals.OS_SEPARATOR}python_framework{globals.OS_SEPARATOR}api{globals.OS_SEPARATOR}resource{globals.OS_SEPARATOR}{KW_OPEN_API}{KW_UI}{globals.OS_SEPARATOR}'
+    # swaggerUi._static_folder = f'{swaggerUi._static_folder}{globals.OS_SEPARATOR}'
+    # swaggerUi._static_folder = f'{swaggerUi._static_folder}{globals.OS_SEPARATOR}'
     apiInstance.documentationFolderPath = swaggerUi._static_folder
     log.debug(addSwagger, f'apiInstance.documentationFolderPath at "{apiInstance.documentationFolderPath}"')
 
